@@ -234,14 +234,12 @@ type ScannerMetrics struct {
 	// Time these metrics were collected
 	CollectedAt time.Time `json:"collected"`
 
-	// Current scanner cycle
-	CurrentCycle uint64 `json:"current_cycle"`
+	CurrentCycle      uint64      `json:"current_cycle"`        // Deprecated Mar 2024
+	CurrentStarted    time.Time   `json:"current_started"`      // Deprecated Mar 2024
+	CyclesCompletedAt []time.Time `json:"cycle_complete_times"` // Deprecated Mar 2024
 
-	// Start time of current cycle
-	CurrentStarted time.Time `json:"current_started"`
-
-	// History of when last cycles completed
-	CyclesCompletedAt []time.Time `json:"cycle_complete_times"`
+	// Number of buckets currently scanning
+	OngoingBuckets int `json:"ongoing_buckets"`
 
 	// Number of accumulated operations by type since server restart.
 	LifeTimeOps map[string]uint64 `json:"life_time_ops,omitempty"`
@@ -296,10 +294,16 @@ func (s *ScannerMetrics) Merge(other *ScannerMetrics) {
 	if other == nil {
 		return
 	}
+
 	if s.CollectedAt.Before(other.CollectedAt) {
 		// Use latest timestamp
 		s.CollectedAt = other.CollectedAt
 	}
+
+	if s.OngoingBuckets < other.OngoingBuckets {
+		s.OngoingBuckets = other.OngoingBuckets
+	}
+
 	if s.CurrentCycle < other.CurrentCycle {
 		s.CurrentCycle = other.CurrentCycle
 		s.CyclesCompletedAt = other.CyclesCompletedAt
@@ -675,6 +679,7 @@ func (m *CPUMetrics) Merge(other *CPUMetrics) {
 type RPCMetrics struct {
 	CollectedAt      time.Time `json:"collectedAt"`
 	Connected        int       `json:"connected"`
+	ReconnectCount   int       `json:"reconnectCount"`
 	Disconnected     int       `json:"disconnected"`
 	OutgoingStreams  int       `json:"outgoingStreams"`
 	IncomingStreams  int       `json:"incomingStreams"`
@@ -684,8 +689,12 @@ type RPCMetrics struct {
 	IncomingMessages int64     `json:"incomingMessages"`
 	OutQueue         int       `json:"outQueue"`
 	LastPongTime     time.Time `json:"lastPongTime"`
+	LastPingMS       float64   `json:"lastPingMS"`
+	MaxPingDurMS     float64   `json:"maxPingDurMS"` // Maximum across all merged entries.
+	LastConnectTime  time.Time `json:"lastConnectTime"`
 
 	ByDestination map[string]RPCMetrics `json:"byDestination,omitempty"`
+	ByCaller      map[string]RPCMetrics `json:"byCaller,omitempty"`
 }
 
 // Merge other into 'm'.
@@ -697,8 +706,12 @@ func (m *RPCMetrics) Merge(other *RPCMetrics) {
 		// Use latest timestamp
 		m.CollectedAt = other.CollectedAt
 	}
+	if m.LastConnectTime.Before(other.LastConnectTime) {
+		m.LastConnectTime = other.LastConnectTime
+	}
 	m.Connected += other.Connected
 	m.Disconnected += other.Disconnected
+	m.ReconnectCount += other.ReconnectCount
 	m.OutgoingStreams += other.OutgoingStreams
 	m.IncomingStreams += other.IncomingStreams
 	m.OutgoingBytes += other.OutgoingBytes
@@ -708,6 +721,10 @@ func (m *RPCMetrics) Merge(other *RPCMetrics) {
 	m.OutQueue += other.OutQueue
 	if m.LastPongTime.Before(other.LastPongTime) {
 		m.LastPongTime = other.LastPongTime
+		m.LastPingMS = other.LastPingMS
+	}
+	if m.MaxPingDurMS < other.MaxPingDurMS {
+		m.MaxPingDurMS = other.MaxPingDurMS
 	}
 	for k, v := range other.ByDestination {
 		if m.ByDestination == nil {
@@ -717,4 +734,12 @@ func (m *RPCMetrics) Merge(other *RPCMetrics) {
 		existing.Merge(&v)
 		m.ByDestination[k] = existing
 	}
+	for k, v := range other.ByCaller {
+		if m.ByCaller == nil {
+			m.ByCaller = make(map[string]RPCMetrics, len(other.ByCaller))
+		}
+		existing := m.ByCaller[k]
+		existing.Merge(&v)
+		m.ByCaller[k] = existing
+	}
 }
