@@ -25,38 +25,41 @@ import (
 	"io"
 	"net/http"
 
+	"github.com/dustin/go-humanize"
 	"github.com/prometheus/common/expfmt"
 	"github.com/prometheus/prom2json"
 )
 
-const (
-	metricsRespBodyLimit = 10 << 20 // 10 MiB
+// MetricsRespBodyLimit sets the top level limit to the size of the
+// metrics results supported by this library.
+var (
+	MetricsRespBodyLimit = int64(humanize.GiByte)
 )
 
 // NodeMetrics - returns Node Metrics in Prometheus format
 //
 //	The client needs to be configured with the endpoint of the desired node
 func (client *MetricsClient) NodeMetrics(ctx context.Context) ([]*prom2json.Family, error) {
-	return client.fetchMetrics(ctx, "node")
+	return client.GetMetrics(ctx, "node")
 }
 
 // ClusterMetrics - returns Cluster Metrics in Prometheus format
 func (client *MetricsClient) ClusterMetrics(ctx context.Context) ([]*prom2json.Family, error) {
-	return client.fetchMetrics(ctx, "cluster")
+	return client.GetMetrics(ctx, "cluster")
 }
 
 // BucketMetrics - returns Bucket Metrics in Prometheus format
 func (client *MetricsClient) BucketMetrics(ctx context.Context) ([]*prom2json.Family, error) {
-	return client.fetchMetrics(ctx, "bucket")
+	return client.GetMetrics(ctx, "bucket")
 }
 
 // ResourceMetrics - returns Resource Metrics in Prometheus format
 func (client *MetricsClient) ResourceMetrics(ctx context.Context) ([]*prom2json.Family, error) {
-	return client.fetchMetrics(ctx, "resource")
+	return client.GetMetrics(ctx, "resource")
 }
 
-// fetchMetrics - returns Metrics of given subsystem in Prometheus format
-func (client *MetricsClient) fetchMetrics(ctx context.Context, subSystem string) ([]*prom2json.Family, error) {
+// GetMetrics - returns Metrics of given subsystem in Prometheus format
+func (client *MetricsClient) GetMetrics(ctx context.Context, subSystem string) ([]*prom2json.Family, error) {
 	reqData := metricsRequestData{
 		relativePath: "/v2/metrics/" + subSystem,
 	}
@@ -72,7 +75,7 @@ func (client *MetricsClient) fetchMetrics(ctx context.Context, subSystem string)
 		return nil, httpRespToErrorResponse(resp)
 	}
 
-	return ParsePrometheusResults(io.LimitReader(resp.Body, metricsRespBodyLimit))
+	return ParsePrometheusResults(io.LimitReader(resp.Body, MetricsRespBodyLimit))
 }
 
 func ParsePrometheusResults(reader io.Reader) (results []*prom2json.Family, err error) {
